fnss.topologies.topology.Topology.buffers — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »

# fnss.topologies.topology.Topology.buffers

`Topology.` `buffers`()

  Return a dictionary of all buffer sizes, keyed by interface

  Returns : | buffers : dict A dictionary of buffer sizes, keyed by interface. The interface is a tuple (u, v) which is the link to which the the interface is outputting

### Navigation

- index
- modules |
- modules |
- FNSS 0.1.2 documentation »